boto v2.21.0 — boto v2.25.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »

# boto v2.21.0

date: | 2013/12/19

This release adds support for the latest AWS OpsWorks, AWS Elastic Beanstalk, Amazon DynamoDB, Amazon Elastic MapReduce (EMR), Amazon Simple Storage Service (S3), Amazon Elastic Transcoder, AWS CloudTrail, and AWS Support APIs. It also includes documentation and other fixes.

Note

Although Boto now includes support for the newly announced China (Beijing) Region, the service endpoints will not be accessible until the Region’s limited preview is launched in early 2014. To find out more about the new Region and request a limited preview account, please visit http://www.amazonaws.cn/.

## Features

- Add support for Elastic Transcoder pagination and new codecs (commit dcb1c5a)
- Add support for new CloudTrail calling format (commit aeafe9b)
- Update to the latest Support API (commit 45e1884)
- Add support for arbitrarily large SQS messages stored in S3 via BigMessage. (issue 1917, commit e6cd665)
- Add support for `encoding_type` to S3 (commit 6b2d967)
- Add support for Elastic MapReduce tags (issue 1928, issue 1920, commit b9749c6, commit 8e4c595)
- Add high level support for global secondary indexes in DynamoDB (issue 1924, issue 1913, commit 32dac5b)
- Add support for Elastic Beanstalk worker environments. (issue 1911, commit bbd4fbf)
- Add support for OpsWorks IAM user permissions per stack (commit ac6e4e7)
- Add support for SigV4 to S3 (commit deb9e18)
- Add support for SigV4 to EC2 (commit bdebfe0)
- Add support for SigV4 to ElastiCache (commit b892b45)

## Bugfixes

- Add documentation describing account usage for multipart uploads in S3 (commit af03d8d)
- Update DesiredCapacity if AutoScalingGroup.desired_capacity is not None. (issue 1906, issue 1906, issue 1757, commit b6670ce)
- Documentation: add Kinesis API reference (issue 1921, commit c169836)
- Documentation: sriovNetSupport instance attribute (issue 1915, commit e1bafcc)
- Update RDS documentation for API version: 2013-09-09 (issue 1914, commit fcf702a)
- Switch all classes to new style classes which results in memory use improvements (commit ca36fa2)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »